@@ -8,8 +8,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-undo-fu-session
 ;; Keywords: convenience
-;; Package-Version: 20251126.1143
-;; Package-Revision: d3067c0063d0
+;; Package-Version: 20260104.1244
+;; Package-Revision: 58bd7f321e6f
 ;; Package-Requires: ((emacs "28.1"))
 
 ;;; Commentary:
@@ -18,7 +18,7 @@
 ;; individual file buffers persistently.
 ;;
 
-;;; Usage
+;;; Usage:
 
 ;;
 ;; Write the following code to your .emacs file:
@@ -61,9 +61,9 @@
       (gv-letplace (getter setter) place
         (funcall setter `(- ,getter ,(or delta 1)))))))
 
-;; Workaround bug in Emacs 30, where this macro fails when to enable
+;; Workaround bug in Emacs 30, where this macro fails to enable
 ;; auto-compression-mode when a file is loaded from the command line.
-;; The problem seems to be `auto-compression-mode' is true,
+;; The problem seems to be that `auto-compression-mode' is true,
 ;; but the mode has not started when undo-fu-session runs.
 ;; Workaround the bug by replacing the auto-compression-mode
 ;; check with `jka-compr-installed-p'.
@@ -81,7 +81,7 @@
              (unless ,already-installed
                (auto-compression-mode 1))
              ,@body)
-         (unless (or ,already-installed)
+         (unless ,already-installed
            (auto-compression-mode -1))
          ;; Restore the initial state (even if it's inconsistent).
          (setq auto-compression-mode ,already-installed-value)))))
@@ -101,11 +101,11 @@
 (defcustom undo-fu-session-directory
   (locate-user-emacs-file "undo-fu-session" ".emacs-undo-fu-session")
   "The directory to store undo data."
-  :type 'string)
+  :type 'directory)
 
 (defcustom undo-fu-session-make-file-name-function 'undo-fu-session-make-file-name
   "The function that computes the session file-path for the current buffer.
-The function takes two arguments (path, extension).
+The function takes two arguments (filepath, extension).
 The returned path must use the extension argument."
   :type 'function)
 
@@ -119,14 +119,14 @@ The returned path must use the extension argument."
 
 (defcustom undo-fu-session-temp-directories
   (cond
-   ((memq system-type (list 'ms-dos 'windows-nt))
+   ((memq system-type '(ms-dos windows-nt))
     (list))
    (t
     (list "/tmp" "/dev/shm")))
   "Temporary directories (must be absolute).
 
 Used by `undo-fu-session-ignore-temp-files' for directories to consider temporary."
-  :type '(repeat string))
+  :type '(repeat directory))
 
 (defcustom undo-fu-session-compression 'gz
   "The type of compression to use or nil.
@@ -153,7 +153,7 @@ to convert existing files to the newly selected format."
   "Number of files to store, nil to disable limiting entirely.
 
 Enforcing removes the oldest files."
-  :type 'integer)
+  :type '(choice (const :tag "Unlimited" nil) natnum))
 
 
 ;; ---------------------------------------------------------------------------
@@ -174,7 +174,7 @@ This is done without adjusting trailing slashes or following links."
   ;; or be relative to the default directory.
   ;;
   ;; Notes:
-  ;; - This is loosely based on `f-same?'` from the `f' library.
+  ;; - This is loosely based on `f-same?' from the `f' library.
   ;;   However it's important this only runs on the user directory and NOT trusted directories
   ;;   since there should never be any ambiguity (which could be caused by expansion)
   ;;   regarding which path is trusted.
@@ -221,12 +221,12 @@ ignoring all branches that aren't included in the current undo state."
       (setq linear-list (cdr linear-list)))
 
     ;; Pass through 'nil', when there is no undo information.
-    ;; Also convert '(list nil)' to 'nil', since this is no undo info too.
+    ;; Also convert '(nil)' to 'nil', since this is no undo info too.
     ;;
     ;; Note that we use 'nil' as this is what `buffer-undo-list' is set
     ;; to when there are no undo steps yet.
     (cond
-     ((and linear-list (null (equal (list nil) linear-list)))
+     ((and linear-list (null (equal '(nil) linear-list)))
       linear-list)
      (t
       nil))))
@@ -235,7 +235,7 @@ ignoring all branches that aren't included in the current undo state."
 ;; Undo Encode/Decode Functionality
 
 (defun undo-fu-session--walk-tree (fn tree)
-  "Operate recursively on undo-list, calling FN TREE."
+  "Operate recursively on undo-list, calling FN on each element of TREE."
   (declare (important-return-value t))
   (cond
    ((consp tree)
@@ -340,7 +340,7 @@ ignoring all branches that aren't included in the current undo state."
 (defun undo-fu-session--next-step (list)
   "Get the next undo step in LIST.
 
-Argument LIST compatible list `buffer-undo-list'."
+Argument LIST a `buffer-undo-list' compatible list."
   (declare (important-return-value t) (side-effect-free error-free))
   (while (car list)
     (setq list (cdr list)))
@@ -349,7 +349,7 @@ Argument LIST compatible list `buffer-undo-list'."
   list)
 
 (defun undo-fu-session--list-to-index-map (list index index-step step-to-index-hash)
-  "Populate the STEP-TO-INDEX-HASH with LIST element.
+  "Populate the STEP-TO-INDEX-HASH with LIST elements.
 
 List elements are used as keys mapping to INDEX by INDEX-STEP."
   (declare (important-return-value nil))
@@ -362,7 +362,7 @@ List elements are used as keys mapping to INDEX by INDEX-STEP."
 (defun undo-fu-session--list-from-index-map (list index index-step step-from-index-hash)
   "Populate the STEP-FROM-INDEX-HASH with INDEX by INDEX-STEP.
 
-INDEX-STEP are used as keys mapping to LIST elements."
+Indices are used as keys mapping to LIST elements."
   (declare (important-return-value nil))
   (unless (eq list t)
     (while list
@@ -372,7 +372,7 @@ INDEX-STEP are used as keys mapping to LIST elements."
 
 (defun undo-fu-session--equivtable-encode (equiv-table buffer-list pending-list)
   "Convert the EQUIV-TABLE into an alist of buffer list indices.
-Argument BUFFER-LIST typically `undo-buffer-list'.
+Argument BUFFER-LIST typically `buffer-undo-list'.
 Argument PENDING-LIST typically `pending-undo-list'."
   (declare (important-return-value t) (side-effect-free error-free))
 
@@ -386,23 +386,22 @@ Argument PENDING-LIST typically `pending-undo-list'."
 
     (maphash
      (lambda (key val)
-       (let ((key-num (gethash key step-to-index-hash))
-             (val-num
-              (cond
-               ((eq t val)
-                t)
-               (t
-                (gethash val step-to-index-hash)))))
-         (when (and key-num val-num)
-           (push (cons key-num val-num) equiv-table-alist))))
+       (when-let* ((key-num (gethash key step-to-index-hash))
+                   (val-num
+                    (cond
+                     ((eq t val)
+                      t)
+                     (t
+                      (gethash val step-to-index-hash)))))
+         (push (cons key-num val-num) equiv-table-alist)))
      equiv-table)
     equiv-table-alist))
 
 
 (defun undo-fu-session--equivtable-decode (equiv-table-alist buffer-list pending-list)
   "Convert EQUIV-TABLE-ALIST into a hash compatible with `undo-equiv-table'.
-Argument BUFFER-LIST an `undo-buffer-list' compatible list.
-Argument PENDING-LIST an `pending-undo-list' compatible list."
+Argument BUFFER-LIST a `buffer-undo-list' compatible list.
+Argument PENDING-LIST a `pending-undo-list' compatible list."
   (declare (important-return-value t) (side-effect-free error-free))
 
   (let* ((equiv-table-length (length equiv-table-alist))
@@ -435,7 +434,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
   (declare (important-return-value nil))
   ;; While errors are highly unlikely in this case,
   ;; clearing old files should _never_ interfere with other operations,
-  ;; so surround with error a check & error message.
+  ;; so surround with an error check & message.
   (condition-case err-1
       (when (file-directory-p undo-fu-session-directory)
         (dolist (file-with-attrs
@@ -496,7 +495,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
       (dolist (file-src-full files-to-convert)
         (let ((file-dst-full (file-name-with-extension file-src-full ext-dst)))
           (message "File %d of %d: %s"
-                   count-complete
+                   (1+ count-complete)
                    count-pending
                    (file-name-nondirectory file-dst-full))
           (condition-case-unless-debug err
@@ -506,7 +505,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
                   ;; Don't create lock-files for the following reasons:
                   ;; - The file name may be too long and fail to lock (see #10).
                   ;; - Locking is already handled by saving the file from which this undo-data
-                  ;;   is created so locking the undo-data if of limited use.
+                  ;;   is created so locking the undo-data is of limited use.
                   ;; - Small but unnecessary overhead.
                   ;;
                   ;; Having said this, there is a theoretical possibility two emacs instances
@@ -515,7 +514,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
                   ;; so there is practically no benefit in writing a file that is "correct" with
                   ;; respect to locking, when the undo-data doesn't match the file contents.
                   ;; In summary, we would either have to lock both files at once, or locking
-                  ;; when writing undo data close to useless.
+                  ;; when writing undo data is close to useless.
                   (let ((create-lockfiles nil))
                     (write-region nil nil file-dst-full nil 0)))
 
@@ -542,11 +541,8 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
   (declare (important-return-value t) (side-effect-free error-free))
 
   (cond
-   ((symbolp undo-fu-session-compression)
+   (undo-fu-session-compression
     (concat "." (symbol-name undo-fu-session-compression)))
-   ((eq undo-fu-session-compression t)
-    ;; Used for older versions where compression was a boolean.
-    ".gz")
    (t
     ".el")))
 
@@ -562,16 +558,16 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
                 undo-fu-session-make-file-name-function)
        (undo-fu-session-make-file-name filename ext)))))
 
-(defun undo-fu-session-make-file-name (filename ext)
-  "Take the path FILENAME, EXT and return a name base on this."
+(defun undo-fu-session-make-file-name (filepath ext)
+  "Take the path FILEPATH and EXT, returning a name based on them."
   (declare (important-return-value t) (side-effect-free error-free))
   (concat
    (file-name-concat undo-fu-session-directory
-                     (url-hexify-string (convert-standard-filename (expand-file-name filename))))
+                     (url-hexify-string (convert-standard-filename (expand-file-name filepath))))
    ext))
 
 (defun undo-fu-session--match-file-name (filename test-files)
-  "Return t if FILENAME match any item in TEST-FILES."
+  "Return t if FILENAME matches any item in TEST-FILES."
   (declare (important-return-value t))
   ;; NOTE: can't be `side-effect-free' because it calls a user defined callback.
   (let ((case-fold-search (file-name-case-insensitive-p filename))
@@ -589,7 +585,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
     found))
 
 (defun undo-fu-session--match-major-mode (mode test-modes)
-  "Return t if MODE match any item in TEST-MODES."
+  "Return t if MODE matches any item in TEST-MODES."
   (declare (important-return-value t) (side-effect-free error-free))
   (let ((found nil))
     (while mode
@@ -633,7 +629,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
   (declare (important-return-value nil))
   (unless (file-directory-p undo-fu-session-directory)
     (make-directory undo-fu-session-directory t)
-    ;; These files should only readable by the owner, see #2.
+    ;; These files should only be readable by the owner, see #2.
     ;; Setting the executable bit is important for directories to be writable.
     (set-file-modes undo-fu-session-directory #o700)))
 
@@ -647,7 +643,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
      ((null filename)
       nil)
      ((and undo-fu-session-ignore-encrypted-files
-           epa-file-handler
+           (bound-and-true-p epa-file-handler)
            (string-match-p (car epa-file-handler) filename))
       nil)
      ((and undo-fu-session-ignore-temp-files (undo-fu-session--temp-file-check filename))
@@ -776,7 +772,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
           (setq content-header (read (current-buffer)))
 
           ;; Use `undo-fu-session--message-without-echo' to avoid distracting the user
-          ;; when a common-place reason for failing to load is hit.
+          ;; when a commonplace reason for failing to load is hit.
           ;;
           ;; These issues are common when working with others on documents.
           ;; This way users may find out why undo didn't load if they need,
@@ -821,8 +817,8 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
         ;; Assign undo data to the current buffer.
         (setq buffer-undo-list emacs-buffer-undo-list)
         (setq pending-undo-list emacs-pending-undo-list)
-        ;; Merge the hash-table since this is a global-variable, share between
-        ;; buffers otherwise this interferes with other buffers undo-only/redo.
+        ;; Merge the hash-table since this is a global variable shared between
+        ;; buffers; otherwise this interferes with other buffers' undo-only/redo.
         (when (hash-table-p emacs-undo-equiv-table)
           (maphash (lambda (key val) (puthash key val undo-equiv-table)) emacs-undo-equiv-table))
         t))))
@@ -870,7 +866,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
 
 (defun undo-fu-session--mode-in-any-buffer ()
   "Return non-nil if the `undo-fu-session-mode' is enabled in any buffer."
-  (declare (side-effect-free error-free))
+  (declare (important-return-value t) (side-effect-free error-free))
   (let ((mode-in-any-buffer nil)
         (buffers (buffer-list)))
     (while buffers
